/* $Id$

   Copyright (C) 2018 Ole Aamot Software
   Author(s): Ole Aamot <ole@gnome.org>
   License: GNU GPL version 3
   Version: 0.0.4 (2018-07-14)
   Website: http://www.gingerblue.org/
 
 */

#include <glib/gstdio.h>
#include <glib/gi18n.h>
#include <gst/gst.h>
#include <gtk/gtk.h>
#include "gingerblue.h"

gint
gb_exit (void) {
	gst_deinit();
	gtk_main_quit();
}

gdouble gb_window_new_volume (GtkVolumeButton *volume, gchar *msg) {
	g_print ("New volume: %0.2f\n", (gdouble) gtk_scale_button_get_value (GTK_SCALE_BUTTON (volume)));
	return (gdouble) gtk_scale_button_get_value (GTK_SCALE_BUTTON (volume));
}
